@@ -1,5 +1,5 @@
-__version__ = 0.30
+__version__ = 0.21
 __copyright__ = 'Copyright (c) 2009, Kyle Fuller'
 __licence__ = 'BSD'
-__author__ = 'Kyle Fuller <inbox@kylefuller.co.uk>, Jannis Leidel (jezdez), krisje8 <krisje8@gmail.com>'
+__author__ = 'Kyle Fuller <inbox@kylefuller.co.uk>, krisje8 <krisje8@gmail.com>'
 __URL__ = 'http://kylefuller.co.uk/project/django-request/'
