@@ -8,7 +8,6 @@ REQUEST_IGNORE_USERNAME = getattr(settings, 'REQUEST_IGNORE_USERNAME', tuple())
 REQUEST_IGNORE_PATHS = getattr(settings, 'REQUEST_IGNORE_PATHS', tuple())
 
 REQUEST_USE_HOSTED_MEDIA = getattr(settings, 'REQUEST_USE_HOSTED_MEDIA', True)
-REQUEST_MEDIA_PREFIX = getattr(settings, 'REQUEST_MEDIA_PREFIX', settings.MEDIA_URL)
 
 REQUEST_TRAFFIC_MODULES = getattr(settings, 'REQUEST_TRAFFIC_MODULES', (
     'request.traffic.UniqueVisitor',
@@ -16,18 +15,6 @@ REQUEST_TRAFFIC_MODULES = getattr(settings, 'REQUEST_TRAFFIC_MODULES', (
     'request.traffic.Hit',
 ))
 
-REQUEST_PLUGINS = getattr(settings, 'REQUEST_PLUGINS', (
-    'request.plugins.TrafficInformation',
-    'request.plugins.LatestRequests',
-    
-    'request.plugins.ActiveUsers',
-    'request.plugins.TopPaths',
-    'request.plugins.TopErrorPaths',
-    'request.plugins.TopReferrers',
-    'request.plugins.TopSearchPhrases',
-    'request.plugins.TopBrowsers',
-))
-
 try:
     REQUEST_BASE_URL = getattr(settings, 'REQUEST_BASE_URL', 'http://%s' % Site.objects.get_current().domain)
 except:
